Orange3 Prototypes
==================
Prototype Orange widgets. Only for the brave.

Installing
----------
This add-on requires Orange3 and Python 3.4 or newer. To install
it, run:

    # Clone the repository and move into it
    git clone https://github.com/biolab/orange3-prototypes.git
    cd orange3-prototypes

    # Setup the add-on
    pip install .

To install Orange in editable/development mode, run

    pip install -e .

Alternatively, you can install the add-on from PyPI:

    pip install orange3-prototypes

